# walkman_modules.convolution_reverb

[![Build Status](https://circleci.com/gh/audiowalkman/walkman_modules.convolution_reverb.svg?style=shield)](https://circleci.com/gh/audiowalkman/walkman_modules.convolution_reverb)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![PyPI version](https://badge.fury.io/py/walkman_modules.convolution_reverb.svg)](https://badge.fury.io/py/walkman_modules.convolution_reverb)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This package adds the `convolution_reverb` module to `walkman`.
